syntax = "proto3";
package sarus_data_spec;

message Relation {
  // Relation between entities e.g.
  // {'name':'sensitive', 'fields':['political leaning']}
  // {'name':'maps_to', 'fields':['location', 'country']}
  // {'name':'maps_to', 'fields':['mass', 'height', 'BMI']} - note that all the first always map to the last otherwise the relation can be split in 2
  // {'name':'equivalent_to', 'fields':['Full name', 'employee id']}
  string uuid = 1;
  string name = 2; // Name of the relation
  repeated string arguments = 3;
  repeated string named_arguments = 4;
  map<string, string> properties = 5; // Other properties
}
