# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sarus_data_spec/protobuf/status.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sarus_data_spec/protobuf/status.proto',
  package='sarus_data_spec',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%sarus_data_spec/protobuf/status.proto\x12\x0fsarus_data_spec\"\xe5\x05\n\x06Status\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61taspec\x18\x02 \x01(\t\x12\x0f\n\x07manager\x18\x03 \x01(\t\x12\x10\n\x08\x64\x61tetime\x18\x04 \x01(\t\x12<\n\x0btask_stages\x18\x05 \x03(\x0b\x32\'.sarus_data_spec.Status.TaskStagesEntry\x12;\n\nproperties\x18\x06 \x03(\x0b\x32\'.sarus_data_spec.Status.PropertiesEntry\x1aP\n\x0fTaskStagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.sarus_data_spec.Status.Stage:\x02\x38\x01\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x97\x03\n\x05Stage\x12\x38\n\x07pending\x18\x01 \x01(\x0b\x32%.sarus_data_spec.Status.Stage.PendingH\x00\x12>\n\nprocessing\x18\x02 \x01(\x0b\x32(.sarus_data_spec.Status.Stage.ProcessingH\x00\x12\x34\n\x05ready\x18\x03 \x01(\x0b\x32#.sarus_data_spec.Status.Stage.ReadyH\x00\x12\x34\n\x05\x65rror\x18\x04 \x01(\x0b\x32#.sarus_data_spec.Status.Stage.ErrorH\x00\x12\x41\n\nproperties\x18\x05 \x03(\x0b\x32-.sarus_data_spec.Status.Stage.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\t\n\x07Pending\x1a\x0c\n\nProcessing\x1a\x07\n\x05Ready\x1a\x07\n\x05\x45rrorB\x07\n\x05stageb\x06proto3'
)




_STATUS_TASKSTAGESENTRY = _descriptor.Descriptor(
  name='TaskStagesEntry',
  full_name='sarus_data_spec.Status.TaskStagesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='sarus_data_spec.Status.TaskStagesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='sarus_data_spec.Status.TaskStagesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=339,
)

_STATUS_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='sarus_data_spec.Status.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='sarus_data_spec.Status.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='sarus_data_spec.Status.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=341,
  serialized_end=390,
)

_STATUS_STAGE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='sarus_data_spec.Status.Stage.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='sarus_data_spec.Status.Stage.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='sarus_data_spec.Status.Stage.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=341,
  serialized_end=390,
)

_STATUS_STAGE_PENDING = _descriptor.Descriptor(
  name='Pending',
  full_name='sarus_data_spec.Status.Stage.Pending',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=750,
  serialized_end=759,
)

_STATUS_STAGE_PROCESSING = _descriptor.Descriptor(
  name='Processing',
  full_name='sarus_data_spec.Status.Stage.Processing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=773,
)

_STATUS_STAGE_READY = _descriptor.Descriptor(
  name='Ready',
  full_name='sarus_data_spec.Status.Stage.Ready',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=782,
)

_STATUS_STAGE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='sarus_data_spec.Status.Stage.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=791,
)

_STATUS_STAGE = _descriptor.Descriptor(
  name='Stage',
  full_name='sarus_data_spec.Status.Stage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pending', full_name='sarus_data_spec.Status.Stage.pending', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing', full_name='sarus_data_spec.Status.Stage.processing', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ready', full_name='sarus_data_spec.Status.Stage.ready', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='sarus_data_spec.Status.Stage.error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='sarus_data_spec.Status.Stage.properties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STATUS_STAGE_PROPERTIESENTRY, _STATUS_STAGE_PENDING, _STATUS_STAGE_PROCESSING, _STATUS_STAGE_READY, _STATUS_STAGE_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='stage', full_name='sarus_data_spec.Status.Stage.stage',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=393,
  serialized_end=800,
)

_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='sarus_data_spec.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='sarus_data_spec.Status.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataspec', full_name='sarus_data_spec.Status.dataspec', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manager', full_name='sarus_data_spec.Status.manager', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datetime', full_name='sarus_data_spec.Status.datetime', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_stages', full_name='sarus_data_spec.Status.task_stages', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='sarus_data_spec.Status.properties', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STATUS_TASKSTAGESENTRY, _STATUS_PROPERTIESENTRY, _STATUS_STAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=800,
)

_STATUS_TASKSTAGESENTRY.fields_by_name['value'].message_type = _STATUS_STAGE
_STATUS_TASKSTAGESENTRY.containing_type = _STATUS
_STATUS_PROPERTIESENTRY.containing_type = _STATUS
_STATUS_STAGE_PROPERTIESENTRY.containing_type = _STATUS_STAGE
_STATUS_STAGE_PENDING.containing_type = _STATUS_STAGE
_STATUS_STAGE_PROCESSING.containing_type = _STATUS_STAGE
_STATUS_STAGE_READY.containing_type = _STATUS_STAGE
_STATUS_STAGE_ERROR.containing_type = _STATUS_STAGE
_STATUS_STAGE.fields_by_name['pending'].message_type = _STATUS_STAGE_PENDING
_STATUS_STAGE.fields_by_name['processing'].message_type = _STATUS_STAGE_PROCESSING
_STATUS_STAGE.fields_by_name['ready'].message_type = _STATUS_STAGE_READY
_STATUS_STAGE.fields_by_name['error'].message_type = _STATUS_STAGE_ERROR
_STATUS_STAGE.fields_by_name['properties'].message_type = _STATUS_STAGE_PROPERTIESENTRY
_STATUS_STAGE.containing_type = _STATUS
_STATUS_STAGE.oneofs_by_name['stage'].fields.append(
  _STATUS_STAGE.fields_by_name['pending'])
_STATUS_STAGE.fields_by_name['pending'].containing_oneof = _STATUS_STAGE.oneofs_by_name['stage']
_STATUS_STAGE.oneofs_by_name['stage'].fields.append(
  _STATUS_STAGE.fields_by_name['processing'])
_STATUS_STAGE.fields_by_name['processing'].containing_oneof = _STATUS_STAGE.oneofs_by_name['stage']
_STATUS_STAGE.oneofs_by_name['stage'].fields.append(
  _STATUS_STAGE.fields_by_name['ready'])
_STATUS_STAGE.fields_by_name['ready'].containing_oneof = _STATUS_STAGE.oneofs_by_name['stage']
_STATUS_STAGE.oneofs_by_name['stage'].fields.append(
  _STATUS_STAGE.fields_by_name['error'])
_STATUS_STAGE.fields_by_name['error'].containing_oneof = _STATUS_STAGE.oneofs_by_name['stage']
_STATUS.fields_by_name['task_stages'].message_type = _STATUS_TASKSTAGESENTRY
_STATUS.fields_by_name['properties'].message_type = _STATUS_PROPERTIESENTRY
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {

  'TaskStagesEntry' : _reflection.GeneratedProtocolMessageType('TaskStagesEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATUS_TASKSTAGESENTRY,
    '__module__' : 'sarus_data_spec.protobuf.status_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Status.TaskStagesEntry)
    })
  ,

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATUS_PROPERTIESENTRY,
    '__module__' : 'sarus_data_spec.protobuf.status_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Status.PropertiesEntry)
    })
  ,

  'Stage' : _reflection.GeneratedProtocolMessageType('Stage', (_message.Message,), {

    'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
      'DESCRIPTOR' : _STATUS_STAGE_PROPERTIESENTRY,
      '__module__' : 'sarus_data_spec.protobuf.status_pb2'
      # @@protoc_insertion_point(class_scope:sarus_data_spec.Status.Stage.PropertiesEntry)
      })
    ,

    'Pending' : _reflection.GeneratedProtocolMessageType('Pending', (_message.Message,), {
      'DESCRIPTOR' : _STATUS_STAGE_PENDING,
      '__module__' : 'sarus_data_spec.protobuf.status_pb2'
      # @@protoc_insertion_point(class_scope:sarus_data_spec.Status.Stage.Pending)
      })
    ,

    'Processing' : _reflection.GeneratedProtocolMessageType('Processing', (_message.Message,), {
      'DESCRIPTOR' : _STATUS_STAGE_PROCESSING,
      '__module__' : 'sarus_data_spec.protobuf.status_pb2'
      # @@protoc_insertion_point(class_scope:sarus_data_spec.Status.Stage.Processing)
      })
    ,

    'Ready' : _reflection.GeneratedProtocolMessageType('Ready', (_message.Message,), {
      'DESCRIPTOR' : _STATUS_STAGE_READY,
      '__module__' : 'sarus_data_spec.protobuf.status_pb2'
      # @@protoc_insertion_point(class_scope:sarus_data_spec.Status.Stage.Ready)
      })
    ,

    'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
      'DESCRIPTOR' : _STATUS_STAGE_ERROR,
      '__module__' : 'sarus_data_spec.protobuf.status_pb2'
      # @@protoc_insertion_point(class_scope:sarus_data_spec.Status.Stage.Error)
      })
    ,
    'DESCRIPTOR' : _STATUS_STAGE,
    '__module__' : 'sarus_data_spec.protobuf.status_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Status.Stage)
    })
  ,
  'DESCRIPTOR' : _STATUS,
  '__module__' : 'sarus_data_spec.protobuf.status_pb2'
  # @@protoc_insertion_point(class_scope:sarus_data_spec.Status)
  })
_sym_db.RegisterMessage(Status)
_sym_db.RegisterMessage(Status.TaskStagesEntry)
_sym_db.RegisterMessage(Status.PropertiesEntry)
_sym_db.RegisterMessage(Status.Stage)
_sym_db.RegisterMessage(Status.Stage.PropertiesEntry)
_sym_db.RegisterMessage(Status.Stage.Pending)
_sym_db.RegisterMessage(Status.Stage.Processing)
_sym_db.RegisterMessage(Status.Stage.Ready)
_sym_db.RegisterMessage(Status.Stage.Error)


_STATUS_TASKSTAGESENTRY._options = None
_STATUS_PROPERTIESENTRY._options = None
_STATUS_STAGE_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)
