# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sarus_data_spec/protobuf/type.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sarus_data_spec.protobuf import predicate_pb2 as sarus__data__spec_dot_protobuf_dot_predicate__pb2
from sarus_data_spec.protobuf import path_pb2 as sarus__data__spec_dot_protobuf_dot_path__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sarus_data_spec/protobuf/type.proto',
  package='sarus_data_spec',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#sarus_data_spec/protobuf/type.proto\x12\x0fsarus_data_spec\x1a(sarus_data_spec/protobuf/predicate.proto\x1a#sarus_data_spec/protobuf/path.proto\"\x86\x14\n\x04Type\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04null\x18\x03 \x01(\x0b\x32\x1a.sarus_data_spec.Type.NullH\x00\x12*\n\x04unit\x18\x04 \x01(\x0b\x32\x1a.sarus_data_spec.Type.UnitH\x00\x12\x30\n\x07\x62oolean\x18\x05 \x01(\x0b\x32\x1d.sarus_data_spec.Type.BooleanH\x00\x12\x30\n\x07integer\x18\x06 \x01(\x0b\x32\x1d.sarus_data_spec.Type.IntegerH\x00\x12*\n\x04\x65num\x18\x07 \x01(\x0b\x32\x1a.sarus_data_spec.Type.EnumH\x00\x12,\n\x05\x66loat\x18\x08 \x01(\x0b\x32\x1b.sarus_data_spec.Type.FloatH\x00\x12*\n\x04text\x18\t \x01(\x0b\x32\x1a.sarus_data_spec.Type.TextH\x00\x12,\n\x05\x62ytes\x18\n \x01(\x0b\x32\x1b.sarus_data_spec.Type.BytesH\x00\x12.\n\x06struct\x18\x0b \x01(\x0b\x32\x1c.sarus_data_spec.Type.StructH\x00\x12,\n\x05union\x18\x0c \x01(\x0b\x32\x1b.sarus_data_spec.Type.UnionH\x00\x12\x32\n\x08optional\x18\r \x01(\x0b\x32\x1e.sarus_data_spec.Type.OptionalH\x00\x12*\n\x04list\x18\x0e \x01(\x0b\x32\x1a.sarus_data_spec.Type.ListH\x00\x12,\n\x05\x61rray\x18\x0f \x01(\x0b\x32\x1b.sarus_data_spec.Type.ArrayH\x00\x12\x32\n\x08\x64\x61tetime\x18\x10 \x01(\x0b\x32\x1e.sarus_data_spec.Type.DatetimeH\x00\x12\x38\n\x0b\x63onstrained\x18\x11 \x01(\x0b\x32!.sarus_data_spec.Type.ConstrainedH\x00\x12\x36\n\nhypothesis\x18\x12 \x01(\x0b\x32 .sarus_data_spec.Type.HypothesisH\x00\x12&\n\x02id\x18\x13 \x01(\x0b\x32\x18.sarus_data_spec.Type.IdH\x00\x12\x39\n\nproperties\x18\x02 \x03(\x0b\x32%.sarus_data_spec.Type.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x06\n\x04Null\x1a\x06\n\x04Unit\x1a\t\n\x07\x42oolean\x1a\xa1\x01\n\x07Integer\x12\x30\n\x04\x62\x61se\x18\x01 \x01(\x0e\x32\".sarus_data_spec.Type.Integer.Base\x12\x0b\n\x03min\x18\x02 \x01(\x03\x12\x0b\n\x03max\x18\x03 \x01(\x03\x12\x17\n\x0fpossible_values\x18\x04 \x03(\x03\"1\n\x04\x42\x61se\x12\t\n\x05INT64\x10\x00\x12\t\n\x05INT32\x10\x01\x12\t\n\x05INT16\x10\x02\x12\x08\n\x04INT8\x10\x03\x1a\xde\x01\n\x04\x45num\x12-\n\x04\x62\x61se\x18\x01 \x01(\x0e\x32\x1f.sarus_data_spec.Type.Enum.Base\x12\x0f\n\x07ordered\x18\x02 \x01(\x08\x12\x39\n\x0bname_values\x18\x03 \x03(\x0b\x32$.sarus_data_spec.Type.Enum.NameValue\x1a(\n\tNameValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03\"1\n\x04\x42\x61se\x12\t\n\x05INT64\x10\x00\x12\t\n\x05INT32\x10\x01\x12\t\n\x05INT16\x10\x02\x12\x08\n\x04INT8\x10\x03\x1a\x99\x01\n\x05\x46loat\x12.\n\x04\x62\x61se\x18\x01 \x01(\x0e\x32 .sarus_data_spec.Type.Float.Base\x12\x0b\n\x03min\x18\x02 \x01(\x01\x12\x0b\n\x03max\x18\x03 \x01(\x01\x12\x17\n\x0fpossible_values\x18\x04 \x03(\x02\"-\n\x04\x42\x61se\x12\x0b\n\x07\x46LOAT64\x10\x00\x12\x0b\n\x07\x46LOAT32\x10\x01\x12\x0b\n\x07\x46LOAT16\x10\x02\x1a\x18\n\x04Text\x12\x10\n\x08\x65ncoding\x18\x01 \x01(\t\x1a\x07\n\x05\x42ytes\x1ax\n\x06Struct\x12\x32\n\x06\x66ields\x18\x01 \x03(\x0b\x32\".sarus_data_spec.Type.Struct.Field\x1a:\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x15.sarus_data_spec.Type\x1av\n\x05Union\x12\x31\n\x06\x66ields\x18\x01 \x03(\x0b\x32!.sarus_data_spec.Type.Union.Field\x1a:\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x15.sarus_data_spec.Type\x1a/\n\x08Optional\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x15.sarus_data_spec.Type\x1a=\n\x04List\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x15.sarus_data_spec.Type\x12\x10\n\x08max_size\x18\x02 \x01(\x03\x1a;\n\x05\x41rray\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x15.sarus_data_spec.Type\x12\r\n\x05shape\x18\x02 \x03(\x03\x1a\xb0\x01\n\x08\x44\x61tetime\x12\x0e\n\x06\x66ormat\x18\x01 \x01(\t\x12\x0b\n\x03min\x18\x02 \x01(\t\x12\x0b\n\x03max\x18\x03 \x01(\t\x12\x17\n\x0fpossible_values\x18\x04 \x03(\t\x12\x31\n\x04\x62\x61se\x18\x05 \x01(\x0e\x32#.sarus_data_spec.Type.Datetime.Base\".\n\x04\x42\x61se\x12\x0c\n\x08INT64_NS\x10\x00\x12\x0c\n\x08INT64_MS\x10\x01\x12\n\n\x06STRING\x10\x02\x1a\x62\n\x0b\x43onstrained\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x15.sarus_data_spec.Type\x12.\n\nconstraint\x18\x02 \x01(\x0b\x32\x1a.sarus_data_spec.Predicate\x1a\x82\x01\n\nHypothesis\x12\x36\n\x05types\x18\x02 \x03(\x0b\x32\'.sarus_data_spec.Type.Hypothesis.Scored\x1a<\n\x06Scored\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x15.sarus_data_spec.Type\x12\r\n\x05score\x18\x02 \x01(\x01\x1a\xb5\x01\n\x02Id\x12+\n\x04\x62\x61se\x18\x01 \x01(\x0e\x32\x1d.sarus_data_spec.Type.Id.Base\x12\x0e\n\x06unique\x18\x02 \x01(\x08\x12(\n\treference\x18\x03 \x01(\x0b\x32\x15.sarus_data_spec.Path\"H\n\x04\x42\x61se\x12\t\n\x05INT64\x10\x00\x12\t\n\x05INT32\x10\x01\x12\t\n\x05INT16\x10\x02\x12\x08\n\x04INT8\x10\x03\x12\n\n\x06STRING\x10\x04\x12\t\n\x05\x42YTES\x10\x05\x42\x06\n\x04typeb\x06proto3'
  ,
  dependencies=[sarus__data__spec_dot_protobuf_dot_predicate__pb2.DESCRIPTOR,sarus__data__spec_dot_protobuf_dot_path__pb2.DESCRIPTOR,])



_TYPE_INTEGER_BASE = _descriptor.EnumDescriptor(
  name='Base',
  full_name='sarus_data_spec.Type.Integer.Base',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INT64', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT32', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT16', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT8', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1218,
  serialized_end=1267,
)
_sym_db.RegisterEnumDescriptor(_TYPE_INTEGER_BASE)

_TYPE_ENUM_BASE = _descriptor.EnumDescriptor(
  name='Base',
  full_name='sarus_data_spec.Type.Enum.Base',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INT64', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT32', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT16', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT8', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1218,
  serialized_end=1267,
)
_sym_db.RegisterEnumDescriptor(_TYPE_ENUM_BASE)

_TYPE_FLOAT_BASE = _descriptor.EnumDescriptor(
  name='Base',
  full_name='sarus_data_spec.Type.Float.Base',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FLOAT64', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOAT32', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOAT16', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1603,
  serialized_end=1648,
)
_sym_db.RegisterEnumDescriptor(_TYPE_FLOAT_BASE)

_TYPE_DATETIME_BASE = _descriptor.EnumDescriptor(
  name='Base',
  full_name='sarus_data_spec.Type.Datetime.Base',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INT64_NS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT64_MS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2231,
  serialized_end=2277,
)
_sym_db.RegisterEnumDescriptor(_TYPE_DATETIME_BASE)

_TYPE_ID_BASE = _descriptor.EnumDescriptor(
  name='Base',
  full_name='sarus_data_spec.Type.Id.Base',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INT64', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT32', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT16', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT8', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BYTES', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2622,
  serialized_end=2694,
)
_sym_db.RegisterEnumDescriptor(_TYPE_ID_BASE)


_TYPE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='sarus_data_spec.Type.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='sarus_data_spec.Type.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='sarus_data_spec.Type.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1027,
  serialized_end=1076,
)

_TYPE_NULL = _descriptor.Descriptor(
  name='Null',
  full_name='sarus_data_spec.Type.Null',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1084,
)

_TYPE_UNIT = _descriptor.Descriptor(
  name='Unit',
  full_name='sarus_data_spec.Type.Unit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1086,
  serialized_end=1092,
)

_TYPE_BOOLEAN = _descriptor.Descriptor(
  name='Boolean',
  full_name='sarus_data_spec.Type.Boolean',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1094,
  serialized_end=1103,
)

_TYPE_INTEGER = _descriptor.Descriptor(
  name='Integer',
  full_name='sarus_data_spec.Type.Integer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='sarus_data_spec.Type.Integer.base', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='sarus_data_spec.Type.Integer.min', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='sarus_data_spec.Type.Integer.max', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='possible_values', full_name='sarus_data_spec.Type.Integer.possible_values', index=3,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TYPE_INTEGER_BASE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1106,
  serialized_end=1267,
)

_TYPE_ENUM_NAMEVALUE = _descriptor.Descriptor(
  name='NameValue',
  full_name='sarus_data_spec.Type.Enum.NameValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sarus_data_spec.Type.Enum.NameValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='sarus_data_spec.Type.Enum.NameValue.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1401,
  serialized_end=1441,
)

_TYPE_ENUM = _descriptor.Descriptor(
  name='Enum',
  full_name='sarus_data_spec.Type.Enum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='sarus_data_spec.Type.Enum.base', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordered', full_name='sarus_data_spec.Type.Enum.ordered', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name_values', full_name='sarus_data_spec.Type.Enum.name_values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TYPE_ENUM_NAMEVALUE, ],
  enum_types=[
    _TYPE_ENUM_BASE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1270,
  serialized_end=1492,
)

_TYPE_FLOAT = _descriptor.Descriptor(
  name='Float',
  full_name='sarus_data_spec.Type.Float',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='sarus_data_spec.Type.Float.base', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='sarus_data_spec.Type.Float.min', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='sarus_data_spec.Type.Float.max', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='possible_values', full_name='sarus_data_spec.Type.Float.possible_values', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TYPE_FLOAT_BASE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1495,
  serialized_end=1648,
)

_TYPE_TEXT = _descriptor.Descriptor(
  name='Text',
  full_name='sarus_data_spec.Type.Text',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoding', full_name='sarus_data_spec.Type.Text.encoding', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1650,
  serialized_end=1674,
)

_TYPE_BYTES = _descriptor.Descriptor(
  name='Bytes',
  full_name='sarus_data_spec.Type.Bytes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1676,
  serialized_end=1683,
)

_TYPE_STRUCT_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='sarus_data_spec.Type.Struct.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sarus_data_spec.Type.Struct.Field.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='sarus_data_spec.Type.Struct.Field.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1747,
  serialized_end=1805,
)

_TYPE_STRUCT = _descriptor.Descriptor(
  name='Struct',
  full_name='sarus_data_spec.Type.Struct',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='sarus_data_spec.Type.Struct.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TYPE_STRUCT_FIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1685,
  serialized_end=1805,
)

_TYPE_UNION_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='sarus_data_spec.Type.Union.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sarus_data_spec.Type.Union.Field.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='sarus_data_spec.Type.Union.Field.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1747,
  serialized_end=1805,
)

_TYPE_UNION = _descriptor.Descriptor(
  name='Union',
  full_name='sarus_data_spec.Type.Union',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='sarus_data_spec.Type.Union.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TYPE_UNION_FIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1807,
  serialized_end=1925,
)

_TYPE_OPTIONAL = _descriptor.Descriptor(
  name='Optional',
  full_name='sarus_data_spec.Type.Optional',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='sarus_data_spec.Type.Optional.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1927,
  serialized_end=1974,
)

_TYPE_LIST = _descriptor.Descriptor(
  name='List',
  full_name='sarus_data_spec.Type.List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='sarus_data_spec.Type.List.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_size', full_name='sarus_data_spec.Type.List.max_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1976,
  serialized_end=2037,
)

_TYPE_ARRAY = _descriptor.Descriptor(
  name='Array',
  full_name='sarus_data_spec.Type.Array',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='sarus_data_spec.Type.Array.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='sarus_data_spec.Type.Array.shape', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2039,
  serialized_end=2098,
)

_TYPE_DATETIME = _descriptor.Descriptor(
  name='Datetime',
  full_name='sarus_data_spec.Type.Datetime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='sarus_data_spec.Type.Datetime.format', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='sarus_data_spec.Type.Datetime.min', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='sarus_data_spec.Type.Datetime.max', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='possible_values', full_name='sarus_data_spec.Type.Datetime.possible_values', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='sarus_data_spec.Type.Datetime.base', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TYPE_DATETIME_BASE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2101,
  serialized_end=2277,
)

_TYPE_CONSTRAINED = _descriptor.Descriptor(
  name='Constrained',
  full_name='sarus_data_spec.Type.Constrained',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='sarus_data_spec.Type.Constrained.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraint', full_name='sarus_data_spec.Type.Constrained.constraint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2279,
  serialized_end=2377,
)

_TYPE_HYPOTHESIS_SCORED = _descriptor.Descriptor(
  name='Scored',
  full_name='sarus_data_spec.Type.Hypothesis.Scored',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='sarus_data_spec.Type.Hypothesis.Scored.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='sarus_data_spec.Type.Hypothesis.Scored.score', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2450,
  serialized_end=2510,
)

_TYPE_HYPOTHESIS = _descriptor.Descriptor(
  name='Hypothesis',
  full_name='sarus_data_spec.Type.Hypothesis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='types', full_name='sarus_data_spec.Type.Hypothesis.types', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TYPE_HYPOTHESIS_SCORED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2380,
  serialized_end=2510,
)

_TYPE_ID = _descriptor.Descriptor(
  name='Id',
  full_name='sarus_data_spec.Type.Id',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='sarus_data_spec.Type.Id.base', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unique', full_name='sarus_data_spec.Type.Id.unique', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference', full_name='sarus_data_spec.Type.Id.reference', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TYPE_ID_BASE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2513,
  serialized_end=2694,
)

_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='sarus_data_spec.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sarus_data_spec.Type.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null', full_name='sarus_data_spec.Type.null', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='sarus_data_spec.Type.unit', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boolean', full_name='sarus_data_spec.Type.boolean', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integer', full_name='sarus_data_spec.Type.integer', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enum', full_name='sarus_data_spec.Type.enum', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float', full_name='sarus_data_spec.Type.float', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='sarus_data_spec.Type.text', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='sarus_data_spec.Type.bytes', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='struct', full_name='sarus_data_spec.Type.struct', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='union', full_name='sarus_data_spec.Type.union', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional', full_name='sarus_data_spec.Type.optional', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list', full_name='sarus_data_spec.Type.list', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array', full_name='sarus_data_spec.Type.array', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datetime', full_name='sarus_data_spec.Type.datetime', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constrained', full_name='sarus_data_spec.Type.constrained', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hypothesis', full_name='sarus_data_spec.Type.hypothesis', index=16,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='sarus_data_spec.Type.id', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='sarus_data_spec.Type.properties', index=18,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TYPE_PROPERTIESENTRY, _TYPE_NULL, _TYPE_UNIT, _TYPE_BOOLEAN, _TYPE_INTEGER, _TYPE_ENUM, _TYPE_FLOAT, _TYPE_TEXT, _TYPE_BYTES, _TYPE_STRUCT, _TYPE_UNION, _TYPE_OPTIONAL, _TYPE_LIST, _TYPE_ARRAY, _TYPE_DATETIME, _TYPE_CONSTRAINED, _TYPE_HYPOTHESIS, _TYPE_ID, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='sarus_data_spec.Type.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=136,
  serialized_end=2702,
)

_TYPE_PROPERTIESENTRY.containing_type = _TYPE
_TYPE_NULL.containing_type = _TYPE
_TYPE_UNIT.containing_type = _TYPE
_TYPE_BOOLEAN.containing_type = _TYPE
_TYPE_INTEGER.fields_by_name['base'].enum_type = _TYPE_INTEGER_BASE
_TYPE_INTEGER.containing_type = _TYPE
_TYPE_INTEGER_BASE.containing_type = _TYPE_INTEGER
_TYPE_ENUM_NAMEVALUE.containing_type = _TYPE_ENUM
_TYPE_ENUM.fields_by_name['base'].enum_type = _TYPE_ENUM_BASE
_TYPE_ENUM.fields_by_name['name_values'].message_type = _TYPE_ENUM_NAMEVALUE
_TYPE_ENUM.containing_type = _TYPE
_TYPE_ENUM_BASE.containing_type = _TYPE_ENUM
_TYPE_FLOAT.fields_by_name['base'].enum_type = _TYPE_FLOAT_BASE
_TYPE_FLOAT.containing_type = _TYPE
_TYPE_FLOAT_BASE.containing_type = _TYPE_FLOAT
_TYPE_TEXT.containing_type = _TYPE
_TYPE_BYTES.containing_type = _TYPE
_TYPE_STRUCT_FIELD.fields_by_name['type'].message_type = _TYPE
_TYPE_STRUCT_FIELD.containing_type = _TYPE_STRUCT
_TYPE_STRUCT.fields_by_name['fields'].message_type = _TYPE_STRUCT_FIELD
_TYPE_STRUCT.containing_type = _TYPE
_TYPE_UNION_FIELD.fields_by_name['type'].message_type = _TYPE
_TYPE_UNION_FIELD.containing_type = _TYPE_UNION
_TYPE_UNION.fields_by_name['fields'].message_type = _TYPE_UNION_FIELD
_TYPE_UNION.containing_type = _TYPE
_TYPE_OPTIONAL.fields_by_name['type'].message_type = _TYPE
_TYPE_OPTIONAL.containing_type = _TYPE
_TYPE_LIST.fields_by_name['type'].message_type = _TYPE
_TYPE_LIST.containing_type = _TYPE
_TYPE_ARRAY.fields_by_name['type'].message_type = _TYPE
_TYPE_ARRAY.containing_type = _TYPE
_TYPE_DATETIME.fields_by_name['base'].enum_type = _TYPE_DATETIME_BASE
_TYPE_DATETIME.containing_type = _TYPE
_TYPE_DATETIME_BASE.containing_type = _TYPE_DATETIME
_TYPE_CONSTRAINED.fields_by_name['type'].message_type = _TYPE
_TYPE_CONSTRAINED.fields_by_name['constraint'].message_type = sarus__data__spec_dot_protobuf_dot_predicate__pb2._PREDICATE
_TYPE_CONSTRAINED.containing_type = _TYPE
_TYPE_HYPOTHESIS_SCORED.fields_by_name['type'].message_type = _TYPE
_TYPE_HYPOTHESIS_SCORED.containing_type = _TYPE_HYPOTHESIS
_TYPE_HYPOTHESIS.fields_by_name['types'].message_type = _TYPE_HYPOTHESIS_SCORED
_TYPE_HYPOTHESIS.containing_type = _TYPE
_TYPE_ID.fields_by_name['base'].enum_type = _TYPE_ID_BASE
_TYPE_ID.fields_by_name['reference'].message_type = sarus__data__spec_dot_protobuf_dot_path__pb2._PATH
_TYPE_ID.containing_type = _TYPE
_TYPE_ID_BASE.containing_type = _TYPE_ID
_TYPE.fields_by_name['null'].message_type = _TYPE_NULL
_TYPE.fields_by_name['unit'].message_type = _TYPE_UNIT
_TYPE.fields_by_name['boolean'].message_type = _TYPE_BOOLEAN
_TYPE.fields_by_name['integer'].message_type = _TYPE_INTEGER
_TYPE.fields_by_name['enum'].message_type = _TYPE_ENUM
_TYPE.fields_by_name['float'].message_type = _TYPE_FLOAT
_TYPE.fields_by_name['text'].message_type = _TYPE_TEXT
_TYPE.fields_by_name['bytes'].message_type = _TYPE_BYTES
_TYPE.fields_by_name['struct'].message_type = _TYPE_STRUCT
_TYPE.fields_by_name['union'].message_type = _TYPE_UNION
_TYPE.fields_by_name['optional'].message_type = _TYPE_OPTIONAL
_TYPE.fields_by_name['list'].message_type = _TYPE_LIST
_TYPE.fields_by_name['array'].message_type = _TYPE_ARRAY
_TYPE.fields_by_name['datetime'].message_type = _TYPE_DATETIME
_TYPE.fields_by_name['constrained'].message_type = _TYPE_CONSTRAINED
_TYPE.fields_by_name['hypothesis'].message_type = _TYPE_HYPOTHESIS
_TYPE.fields_by_name['id'].message_type = _TYPE_ID
_TYPE.fields_by_name['properties'].message_type = _TYPE_PROPERTIESENTRY
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['null'])
_TYPE.fields_by_name['null'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['unit'])
_TYPE.fields_by_name['unit'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['boolean'])
_TYPE.fields_by_name['boolean'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['integer'])
_TYPE.fields_by_name['integer'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['enum'])
_TYPE.fields_by_name['enum'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['float'])
_TYPE.fields_by_name['float'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['text'])
_TYPE.fields_by_name['text'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['bytes'])
_TYPE.fields_by_name['bytes'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['struct'])
_TYPE.fields_by_name['struct'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['union'])
_TYPE.fields_by_name['union'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['optional'])
_TYPE.fields_by_name['optional'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['list'])
_TYPE.fields_by_name['list'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['array'])
_TYPE.fields_by_name['array'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['datetime'])
_TYPE.fields_by_name['datetime'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['constrained'])
_TYPE.fields_by_name['constrained'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['hypothesis'])
_TYPE.fields_by_name['hypothesis'].containing_oneof = _TYPE.oneofs_by_name['type']
_TYPE.oneofs_by_name['type'].fields.append(
  _TYPE.fields_by_name['id'])
_TYPE.fields_by_name['id'].containing_oneof = _TYPE.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['Type'] = _TYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Type = _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_PROPERTIESENTRY,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.PropertiesEntry)
    })
  ,

  'Null' : _reflection.GeneratedProtocolMessageType('Null', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_NULL,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Null)
    })
  ,

  'Unit' : _reflection.GeneratedProtocolMessageType('Unit', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_UNIT,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Unit)
    })
  ,

  'Boolean' : _reflection.GeneratedProtocolMessageType('Boolean', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_BOOLEAN,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Boolean)
    })
  ,

  'Integer' : _reflection.GeneratedProtocolMessageType('Integer', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_INTEGER,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Integer)
    })
  ,

  'Enum' : _reflection.GeneratedProtocolMessageType('Enum', (_message.Message,), {

    'NameValue' : _reflection.GeneratedProtocolMessageType('NameValue', (_message.Message,), {
      'DESCRIPTOR' : _TYPE_ENUM_NAMEVALUE,
      '__module__' : 'sarus_data_spec.protobuf.type_pb2'
      # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Enum.NameValue)
      })
    ,
    'DESCRIPTOR' : _TYPE_ENUM,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Enum)
    })
  ,

  'Float' : _reflection.GeneratedProtocolMessageType('Float', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_FLOAT,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Float)
    })
  ,

  'Text' : _reflection.GeneratedProtocolMessageType('Text', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_TEXT,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Text)
    })
  ,

  'Bytes' : _reflection.GeneratedProtocolMessageType('Bytes', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_BYTES,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Bytes)
    })
  ,

  'Struct' : _reflection.GeneratedProtocolMessageType('Struct', (_message.Message,), {

    'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
      'DESCRIPTOR' : _TYPE_STRUCT_FIELD,
      '__module__' : 'sarus_data_spec.protobuf.type_pb2'
      # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Struct.Field)
      })
    ,
    'DESCRIPTOR' : _TYPE_STRUCT,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Struct)
    })
  ,

  'Union' : _reflection.GeneratedProtocolMessageType('Union', (_message.Message,), {

    'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
      'DESCRIPTOR' : _TYPE_UNION_FIELD,
      '__module__' : 'sarus_data_spec.protobuf.type_pb2'
      # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Union.Field)
      })
    ,
    'DESCRIPTOR' : _TYPE_UNION,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Union)
    })
  ,

  'Optional' : _reflection.GeneratedProtocolMessageType('Optional', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_OPTIONAL,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Optional)
    })
  ,

  'List' : _reflection.GeneratedProtocolMessageType('List', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_LIST,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.List)
    })
  ,

  'Array' : _reflection.GeneratedProtocolMessageType('Array', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_ARRAY,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Array)
    })
  ,

  'Datetime' : _reflection.GeneratedProtocolMessageType('Datetime', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_DATETIME,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Datetime)
    })
  ,

  'Constrained' : _reflection.GeneratedProtocolMessageType('Constrained', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_CONSTRAINED,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Constrained)
    })
  ,

  'Hypothesis' : _reflection.GeneratedProtocolMessageType('Hypothesis', (_message.Message,), {

    'Scored' : _reflection.GeneratedProtocolMessageType('Scored', (_message.Message,), {
      'DESCRIPTOR' : _TYPE_HYPOTHESIS_SCORED,
      '__module__' : 'sarus_data_spec.protobuf.type_pb2'
      # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Hypothesis.Scored)
      })
    ,
    'DESCRIPTOR' : _TYPE_HYPOTHESIS,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Hypothesis)
    })
  ,

  'Id' : _reflection.GeneratedProtocolMessageType('Id', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_ID,
    '__module__' : 'sarus_data_spec.protobuf.type_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Type.Id)
    })
  ,
  'DESCRIPTOR' : _TYPE,
  '__module__' : 'sarus_data_spec.protobuf.type_pb2'
  # @@protoc_insertion_point(class_scope:sarus_data_spec.Type)
  })
_sym_db.RegisterMessage(Type)
_sym_db.RegisterMessage(Type.PropertiesEntry)
_sym_db.RegisterMessage(Type.Null)
_sym_db.RegisterMessage(Type.Unit)
_sym_db.RegisterMessage(Type.Boolean)
_sym_db.RegisterMessage(Type.Integer)
_sym_db.RegisterMessage(Type.Enum)
_sym_db.RegisterMessage(Type.Enum.NameValue)
_sym_db.RegisterMessage(Type.Float)
_sym_db.RegisterMessage(Type.Text)
_sym_db.RegisterMessage(Type.Bytes)
_sym_db.RegisterMessage(Type.Struct)
_sym_db.RegisterMessage(Type.Struct.Field)
_sym_db.RegisterMessage(Type.Union)
_sym_db.RegisterMessage(Type.Union.Field)
_sym_db.RegisterMessage(Type.Optional)
_sym_db.RegisterMessage(Type.List)
_sym_db.RegisterMessage(Type.Array)
_sym_db.RegisterMessage(Type.Datetime)
_sym_db.RegisterMessage(Type.Constrained)
_sym_db.RegisterMessage(Type.Hypothesis)
_sym_db.RegisterMessage(Type.Hypothesis.Scored)
_sym_db.RegisterMessage(Type.Id)


_TYPE_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)
