syntax = "proto3";
package sarus_data_spec;

message Manager {
  // A mnager must register itself
  string uuid = 1; // e.g. RFC 4122 id used to refer to the dataset (content linked?)
  map<string, string> properties = 2; // Other properties
}
