# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sarus_data_spec/protobuf/predicate.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sarus_data_spec/protobuf/predicate.proto',
  package='sarus_data_spec',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(sarus_data_spec/protobuf/predicate.proto\x12\x0fsarus_data_spec\"\xab\x04\n\tPredicate\x12\x33\n\x06simple\x18\x01 \x01(\x0b\x32!.sarus_data_spec.Predicate.SimpleH\x00\x12\x31\n\x05inter\x18\x02 \x01(\x0b\x32 .sarus_data_spec.Predicate.InterH\x00\x12\x31\n\x05union\x18\x03 \x01(\x0b\x32 .sarus_data_spec.Predicate.UnionH\x00\x12/\n\x04\x63omp\x18\x04 \x01(\x0b\x32\x1f.sarus_data_spec.Predicate.CompH\x00\x12>\n\nproperties\x18\x05 \x03(\x0b\x32*.sarus_data_spec.Predicate.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a)\n\x06Simple\x12\x10\n\x08operator\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x37\n\x05Inter\x12.\n\npredicates\x18\x01 \x03(\x0b\x32\x1a.sarus_data_spec.Predicate\x1a\x37\n\x05Union\x12.\n\npredicates\x18\x01 \x03(\x0b\x32\x1a.sarus_data_spec.Predicate\x1a\x35\n\x04\x43omp\x12-\n\tpredicate\x18\x01 \x01(\x0b\x32\x1a.sarus_data_spec.PredicateB\x0b\n\tpredicateb\x06proto3'
)




_PREDICATE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='sarus_data_spec.Predicate.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='sarus_data_spec.Predicate.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='sarus_data_spec.Predicate.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=392,
)

_PREDICATE_SIMPLE = _descriptor.Descriptor(
  name='Simple',
  full_name='sarus_data_spec.Predicate.Simple',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operator', full_name='sarus_data_spec.Predicate.Simple.operator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='sarus_data_spec.Predicate.Simple.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=435,
)

_PREDICATE_INTER = _descriptor.Descriptor(
  name='Inter',
  full_name='sarus_data_spec.Predicate.Inter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicates', full_name='sarus_data_spec.Predicate.Inter.predicates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=437,
  serialized_end=492,
)

_PREDICATE_UNION = _descriptor.Descriptor(
  name='Union',
  full_name='sarus_data_spec.Predicate.Union',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicates', full_name='sarus_data_spec.Predicate.Union.predicates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=549,
)

_PREDICATE_COMP = _descriptor.Descriptor(
  name='Comp',
  full_name='sarus_data_spec.Predicate.Comp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicate', full_name='sarus_data_spec.Predicate.Comp.predicate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=604,
)

_PREDICATE = _descriptor.Descriptor(
  name='Predicate',
  full_name='sarus_data_spec.Predicate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='simple', full_name='sarus_data_spec.Predicate.simple', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inter', full_name='sarus_data_spec.Predicate.inter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='union', full_name='sarus_data_spec.Predicate.union', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comp', full_name='sarus_data_spec.Predicate.comp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='sarus_data_spec.Predicate.properties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PREDICATE_PROPERTIESENTRY, _PREDICATE_SIMPLE, _PREDICATE_INTER, _PREDICATE_UNION, _PREDICATE_COMP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='predicate', full_name='sarus_data_spec.Predicate.predicate',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=62,
  serialized_end=617,
)

_PREDICATE_PROPERTIESENTRY.containing_type = _PREDICATE
_PREDICATE_SIMPLE.containing_type = _PREDICATE
_PREDICATE_INTER.fields_by_name['predicates'].message_type = _PREDICATE
_PREDICATE_INTER.containing_type = _PREDICATE
_PREDICATE_UNION.fields_by_name['predicates'].message_type = _PREDICATE
_PREDICATE_UNION.containing_type = _PREDICATE
_PREDICATE_COMP.fields_by_name['predicate'].message_type = _PREDICATE
_PREDICATE_COMP.containing_type = _PREDICATE
_PREDICATE.fields_by_name['simple'].message_type = _PREDICATE_SIMPLE
_PREDICATE.fields_by_name['inter'].message_type = _PREDICATE_INTER
_PREDICATE.fields_by_name['union'].message_type = _PREDICATE_UNION
_PREDICATE.fields_by_name['comp'].message_type = _PREDICATE_COMP
_PREDICATE.fields_by_name['properties'].message_type = _PREDICATE_PROPERTIESENTRY
_PREDICATE.oneofs_by_name['predicate'].fields.append(
  _PREDICATE.fields_by_name['simple'])
_PREDICATE.fields_by_name['simple'].containing_oneof = _PREDICATE.oneofs_by_name['predicate']
_PREDICATE.oneofs_by_name['predicate'].fields.append(
  _PREDICATE.fields_by_name['inter'])
_PREDICATE.fields_by_name['inter'].containing_oneof = _PREDICATE.oneofs_by_name['predicate']
_PREDICATE.oneofs_by_name['predicate'].fields.append(
  _PREDICATE.fields_by_name['union'])
_PREDICATE.fields_by_name['union'].containing_oneof = _PREDICATE.oneofs_by_name['predicate']
_PREDICATE.oneofs_by_name['predicate'].fields.append(
  _PREDICATE.fields_by_name['comp'])
_PREDICATE.fields_by_name['comp'].containing_oneof = _PREDICATE.oneofs_by_name['predicate']
DESCRIPTOR.message_types_by_name['Predicate'] = _PREDICATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Predicate = _reflection.GeneratedProtocolMessageType('Predicate', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _PREDICATE_PROPERTIESENTRY,
    '__module__' : 'sarus_data_spec.protobuf.predicate_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Predicate.PropertiesEntry)
    })
  ,

  'Simple' : _reflection.GeneratedProtocolMessageType('Simple', (_message.Message,), {
    'DESCRIPTOR' : _PREDICATE_SIMPLE,
    '__module__' : 'sarus_data_spec.protobuf.predicate_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Predicate.Simple)
    })
  ,

  'Inter' : _reflection.GeneratedProtocolMessageType('Inter', (_message.Message,), {
    'DESCRIPTOR' : _PREDICATE_INTER,
    '__module__' : 'sarus_data_spec.protobuf.predicate_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Predicate.Inter)
    })
  ,

  'Union' : _reflection.GeneratedProtocolMessageType('Union', (_message.Message,), {
    'DESCRIPTOR' : _PREDICATE_UNION,
    '__module__' : 'sarus_data_spec.protobuf.predicate_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Predicate.Union)
    })
  ,

  'Comp' : _reflection.GeneratedProtocolMessageType('Comp', (_message.Message,), {
    'DESCRIPTOR' : _PREDICATE_COMP,
    '__module__' : 'sarus_data_spec.protobuf.predicate_pb2'
    # @@protoc_insertion_point(class_scope:sarus_data_spec.Predicate.Comp)
    })
  ,
  'DESCRIPTOR' : _PREDICATE,
  '__module__' : 'sarus_data_spec.protobuf.predicate_pb2'
  # @@protoc_insertion_point(class_scope:sarus_data_spec.Predicate)
  })
_sym_db.RegisterMessage(Predicate)
_sym_db.RegisterMessage(Predicate.PropertiesEntry)
_sym_db.RegisterMessage(Predicate.Simple)
_sym_db.RegisterMessage(Predicate.Inter)
_sym_db.RegisterMessage(Predicate.Union)
_sym_db.RegisterMessage(Predicate.Comp)


_PREDICATE_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)
